@@ -17,23 +17,28 @@
 <context>
     <name>Notifyd</name>
     <message>
-        <location filename="../notifyd.cpp" line="272"/>
+        <location filename="../notifyd.cpp" line="274"/>
         <source>Clear All</source>
         <translation>Clear All</translation>
     </message>
     <message>
-        <location filename="../notifyd.cpp" line="280"/>
+        <location filename="../notifyd.cpp" line="285"/>
+        <source>Do Not Disturb</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../notifyd.cpp" line="293"/>
         <source>Options</source>
         <translation>Options</translation>
     </message>
     <message numerus="yes">
-        <location filename="../notifyd.cpp" line="287"/>
-        <location filename="../notifyd.cpp" line="344"/>
-        <location filename="../notifyd.cpp" line="364"/>
+        <location filename="../notifyd.cpp" line="300"/>
+        <location filename="../notifyd.cpp" line="358"/>
+        <location filename="../notifyd.cpp" line="379"/>
         <source>%n Unattended Notification(s)</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <translation>
+            <numerusform>%n Unattended Notification</numerusform>
+            <numerusform>%n Unattended Notifications</numerusform>
         </translation>
     </message>
 </context>
